%% This code performs the Montecarlo experiment to find the bias of the
% policy rules with Markov-switching coefficients

%% Setting up parameters
alpha_1 = 0.5;
alpha_2 = 1.5;
alpha = [alpha_1 alpha_2];
sigma1 = 0.1;
gamma_1 = 0;
gamma_2 = 0.1;
gamma = [gamma_1 gamma_2];
sigma2 = 0.01;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% j = 1 <-- j1 = 1, j2 = 1;
% j = 2 <-- j1 = 2, j2 = 1;
% j = 3 <-- j1 = 1, j2 = 2;
% j = 4 <-- j1 = 2, j2 = 2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% p_ij = P(S_t = i|S_{t-1} = j)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Correlation = 0.67
% p_11 = 0.3;
% p_21 = 0.05;
% p_31 = 0.05;
% p_41 = 1-p_11-p_21-p_31;
% p_12 = 0.2;
% p_22 = 0.05;
% p_32 = 0.05;
% p_42 = 1-p_12-p_22-p_32;
% p_13 = 0.2;
% p_23 = 0.05;
% p_33 = 0.05;
% p_43 = 1-p_13-p_23-p_33;
% p_14 = 0.1;
% p_24 = 0.05;
% p_44 = 0.8;
% p_34 = 1-p_14-p_24-p_44;
% 
% P = [p_11 p_12 p_13 p_14;
%      p_21 p_22 p_23 p_24;
%      p_31 p_32 p_33 p_34;
%      p_41 p_42 p_43 p_44];
 
 
% % Correlation = 0
% P = 0.25*ones(4,4);

% Correlation = 1
p_11 = 0.3;
p_21 = 0.001;
p_31 = 0.001;
p_41 = 1-p_11-p_21-p_31;
p_12 = 0.2;
p_22 = 0.001;
p_32 = 0.001;
p_42 = 1-p_12-p_22-p_32;
p_13 = 0.2;
p_23 = 0.001;
p_33 = 0.001;
p_43 = 1-p_13-p_23-p_33;
p_14 = 0.2;
p_24 = 0.001;
p_44 = 0.798;
p_34 = 1-p_14-p_24-p_44;

P = [p_11 p_12 p_13 p_14;
     p_21 p_22 p_23 p_24;
     p_31 p_32 p_33 p_34;
     p_41 p_42 p_43 p_44];
 
% Obtaining unconditional probabilities
A = [eye(4)-P;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5); % unconditional probabilities vector

% Marginal transition probabilities [from Kim(2009)]
p1_11 = (p(1)*(P(1,1)+P(3,1))+p(3)*(P(1,3)+P(3,3)))/(p(1)+p(3));
p1_22 = (p(2)*(P(2,2)+P(4,2))+p(4)*(P(2,4)+P(4,4)))/(p(2)+p(4));

T = 200; % sample size  
zlb_fraction = 0.25; % Fraction of the time/sample that y1 = 0
Tzlb = zlb_fraction*T; % Number of periods for which y1 = 0

%% Montecarlo simulation
param0_NDT = [alpha_1;alpha_2;log(sigma1);log(p1_11/(1-p1_11));log(p1_22/(1-p1_22))];
param0_ND = param0_NDT;
transprob0 = zeros(12,1);
options = optimset('Display','iter');
transprob = transformedprobabilities(P); % To obtain initial values for transformed probabilities
x_11 = transprob(1);
x_21 = transprob(2); 
x_31 = transprob(3); 
x_12 = transprob(4);
x_22 = transprob(5);
x_32 = transprob(6);
x_13 = transprob(7);
x_23 = transprob(8);
x_33 = transprob(9);
x_14 = transprob(10);
x_24 = transprob(11);
x_44 = transprob(12);
param0 = [alpha_1;alpha_2;log(sigma1);gamma_1;gamma_2;log(sigma2);x_11;x_21;x_31;x_12;x_22;x_32;x_13;x_23;x_33;x_14;x_24;x_44];
%%
m = 1000; % number of Montecarlo simulations
% NDT: Model with No joint estimation nor Tobit specification
% ND: Model with No joint estimation but with Tobit specification
% random_u: Only the errors of the equations are random across simulations
% random_s: Only the regimes are random across simulations
% random_both: Both u and s are random (this is the relevant case)
bias_alpha_NDT_random_u = zeros(m,3);
bias_p_NDT_random_u = zeros(m,2);
bias_alpha_ND_random_u = zeros(m,3);
bias_p_ND_random_u = zeros(m,2);
bias_alpha_random_u = zeros(m,3);
bias_p_random_u = zeros(m,2);
bias_alpha_NDT_random_s = zeros(m,3);
bias_p_NDT_random_s = zeros(m,2);
bias_alpha_ND_random_s = zeros(m,3);
bias_p_ND_random_s = zeros(m,2);
bias_alpha_random_s = zeros(m,3);
bias_p_random_s = zeros(m,2);
bias_alpha_NDT_random_both = zeros(m,3);
bias_p_NDT_random_both = zeros(m,2);
bias_alpha_ND_random_both = zeros(m,3);
bias_p_ND_random_both = zeros(m,2);
bias_alpha_random_both = zeros(m,3);
bias_p_random_both = zeros(m,2);
bias_p1_1t_NDT_random_u = zeros(T,m);
bias_p1_1t_ND_random_u = zeros(T,m);
bias_p1_1t_random_u = zeros(T,m);
bias_p1_1t_NDT_random_s = zeros(T,m);
bias_p1_1t_ND_random_s = zeros(T,m);
bias_p1_1t_random_s = zeros(T,m);
bias_p1_1t_NDT_random_both = zeros(T,m);
bias_p1_1t_ND_random_both = zeros(T,m);
bias_p1_1t_random_both = zeros(T,m);
corrSm = zeros(m,1);

x1 = [1+rand(T-Tzlb,1);-1+rand(Tzlb,1)]; % x1 is U(1,2) in the first part of the sample and U(-1,0) in the second part where the zlb is binding
x2 = rand(T,1);
u1 = randn(T,m);
u2 = randn(T,m);
randomstates = rand(T,m);
u1_s = u1(:,1);
u2_s = u2(:,1);
randomstates_u = randomstates(:,1);
tic;
parfor i=1:m
    [bias_alpha_NDT, bias_alpha_ND, bias_alpha, bias_p_NDT, bias_p_ND, bias_p, bias_p1_1t_NDT, bias_p1_1t_ND, bias_p1_1t] = bias_random_u(alpha,sigma1,gamma,sigma2,P,T,x1,x2,u1(:,i),u2(:,i),randomstates_u,param0_NDT,param0_ND,param0);
    bias_alpha_NDT_random_u(i,:) = bias_alpha_NDT;
    bias_p_NDT_random_u(i,:) = bias_p_NDT;
    bias_alpha_ND_random_u(i,:) = bias_alpha_ND;
    bias_p_ND_random_u(i,:) = bias_p_ND;
    bias_alpha_random_u(i,:) = bias_alpha;
    bias_p_random_u(i,:) = bias_p;
    bias_p1_1t_NDT_random_u(:,i) = bias_p1_1t_NDT;
    bias_p1_1t_ND_random_u(:,i) = bias_p1_1t_ND;
    bias_p1_1t_random_u(:,i) = bias_p1_1t;
    [bias_alpha_NDT, bias_alpha_ND, bias_alpha, bias_p_NDT, bias_p_ND, bias_p, bias_p1_1t_NDT, bias_p1_1t_ND, bias_p1_1t, corrS] = bias_random_s(alpha,sigma1,gamma,sigma2,P,T,x1,x2,u1_s,u2_s,randomstates(:,i),param0_NDT,param0_ND,param0);
    bias_alpha_NDT_random_s(i,:) = bias_alpha_NDT;
    bias_p_NDT_random_s(i,:) = bias_p_NDT;
    bias_alpha_ND_random_s(i,:) = bias_alpha_ND;
    bias_p_ND_random_s(i,:) = bias_p_ND;
    bias_alpha_random_s(i,:) = bias_alpha;
    bias_p_random_s(i,:) = bias_p;
    bias_p1_1t_NDT_random_s(:,i) = bias_p1_1t_NDT;
    bias_p1_1t_ND_random_s(:,i) = bias_p1_1t_ND;
    bias_p1_1t_random_s(:,i) = bias_p1_1t;
    corrSm(i) = corrS;
    [bias_alpha_NDT, bias_alpha_ND, bias_alpha, bias_p_NDT, bias_p_ND, bias_p, bias_p1_1t_NDT, bias_p1_1t_ND, bias_p1_1t] = bias_random_both(alpha,sigma1,gamma,sigma2,P,T,x1,x2,u1(:,i),u2(:,i),randomstates(:,i),param0_NDT,param0_ND,param0);
    bias_alpha_NDT_random_both(i,:) = bias_alpha_NDT;
    bias_p_NDT_random_both(i,:) = bias_p_NDT;
    bias_alpha_ND_random_both(i,:) = bias_alpha_ND;
    bias_p_ND_random_both(i,:) = bias_p_ND;
    bias_alpha_random_both(i,:) = bias_alpha;
    bias_p_random_both(i,:) = bias_p;
    bias_p1_1t_NDT_random_both(:,i) = bias_p1_1t_NDT;
    bias_p1_1t_ND_random_both(:,i) = bias_p1_1t_ND;
    bias_p1_1t_random_both(:,i) = bias_p1_1t;
end;
toc;
%%
% save('bias_alpha_NDT_random_u','bias_alpha_NDT_random_u');
% save('bias_alpha_ND_random_u','bias_alpha_ND_random_u');
% save('bias_alpha_random_u','bias_alpha_random_u');
% save('bias_alpha_NDT_random_s','bias_alpha_NDT_random_s');
% save('bias_alpha_ND_random_s','bias_alpha_ND_random_s');
% save('bias_alpha_random_s','bias_alpha_random_s');
% save('bias_alpha_NDT_random_both','bias_alpha_NDT_random_both');
% save('bias_alpha_ND_random_both','bias_alpha_ND_random_both');
% save('bias_alpha_random_both','bias_alpha_random_both');
% save('bias_p_NDT_random_u','bias_p_NDT_random_u');
% save('bias_p_ND_random_u','bias_p_ND_random_u');
% save('bias_p_random_u','bias_p_random_u');
% save('bias_p_NDT_random_s','bias_p_NDT_random_s');
% save('bias_p_ND_random_s','bias_p_ND_random_s');
% save('bias_p_random_s','bias_p_random_s');
% save('bias_p_NDT_random_both','bias_p_NDT_random_both');
% save('bias_p_ND_random_both','bias_p_ND_random_both');
% save('bias_p_random_both','bias_p_random_both');
% save('bias_p1_1t_NDT_random_u','bias_p1_1t_NDT_random_u');
% save('bias_p1_1t_ND_random_u','bias_p1_1t_ND_random_u');
% save('bias_p1_1t_random_u','bias_p1_1t_random_u');
% save('bias_p1_1t_NDT_random_s','bias_p1_1t_NDT_random_s');
% save('bias_p1_1t_ND_random_s','bias_p1_1t_ND_random_s');
% save('bias_p1_1t_random_s','bias_p1_1t_random_s');
% save('bias_p1_1t_NDT_random_both','bias_p1_1t_NDT_random_both');
% save('bias_p1_1t_ND_random_both','bias_p1_1t_ND_random_both');
% save('bias_p1_1t_random_both','bias_p1_1t_random_both');
% save('corrSm','corrSm');
