function [bias_alpha_NDT, bias_alpha_ND, bias_alpha, bias_p_NDT, bias_p_ND, bias_p, bias_p1_1t_NDT, bias_p1_1t_ND, bias_p1_1t] = bias_random_u(alpha,sigma1,gamma,sigma2,P,T,x1,x2,u1,u2,randomstates,param0_NDT,param0_ND,param0)

%% Setting up parameters
% Obtaining unconditional probabilities
A = [eye(4)-P;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5); % unconditional probabilities vector

% Marginal transition probabilities [from Kim(2009)]
p1_11 = (p(1)*(P(1,1)+P(3,1))+p(3)*(P(1,3)+P(3,3)))/(p(1)+p(3));
p1_22 = (p(2)*(P(2,2)+P(4,2))+p(4)*(P(2,4)+P(4,4)))/(p(2)+p(4));

%% Simulating series
mj1 = [1;2;1;2]; % set of states for Sy1 for j=1,2,3,4
mj2 = [1;1;2;2]; % set of states for Sy2 for j=1,2,3,4
j = sum(cumsum(p)<randomstates(1))+1; % initial state for S
S = [j;zeros(T-1,1)]; % vector of joint states
alpham = [alpha(mj1(j));zeros(T-1,1)]; % vector of alphas
gammam = [gamma(mj2(j));zeros(T-1,1)]; % vector of gammas

for t = 2:T
    j = sum(cumsum(P(:,j))<randomstates(t))+1; % today's state based on yesterday's state
    S(t) = j;
    alpham(t) = alpha(mj1(j));
    gammam(t) = gamma(mj2(j));
end;

y1star = alpham.*x1 + sigma1*u1;
y2 = gammam.*x2 + sigma2*u2;
y1 = max([zeros(1,T);y1star'])';
p1_1t = (alpham==alpha(1)); 

%% Estimation of M-S model for y1 ignoring dependent switching and censoring
data = [y1 x1];
param_NDT = fminunc(@(param)loglikfuny1marginal(param,data),param0_NDT);

% Obtaining smoothed probabilities
[~, ~, smooth_prob] = estimatedproby1marginal(param_NDT,data);
smooth_p1_1t_NDT = smooth_prob(:,1);

% Obtaining results
alpha_1_est_NDT = param_NDT(1);
alpha_2_est_NDT = param_NDT(2);
sigma1_est_NDT = exp(param_NDT(3));
p1_11_est_NDT = exp(param_NDT(4))/(1+exp(param_NDT(4)));
p1_22_est_NDT = exp(param_NDT(5))/(1+exp(param_NDT(5)));

%% Estimation of M-S model for y1 ignoring dependent switching
data = [y1 x1];
param_ND = fminunc(@(param)loglikfuny1marginalTOBIT(param,data),param0_ND);

% Obtaining smoothed probabilities
[~, ~, smooth_prob] = estimatedproby1marginalTOBIT(param_ND,data);
smooth_p1_1t_ND = smooth_prob(:,1);

% Obtaining results
alpha_1_est_ND = param_ND(1);
alpha_2_est_ND = param_ND(2);
sigma1_est_ND = exp(param_ND(3));
p1_11_est_ND = exp(param_ND(4))/(1+exp(param_ND(4)));
p1_22_est_ND = exp(param_ND(5))/(1+exp(param_ND(5)));

%% Joint estimation of M-S model
data = [y1 y2 x1 x2];
options = optimset('MaxFunEvals',1000000,'MaxIter',1000000);
param = fminunc(@(param)loglikfunyjoint(param,data),param0,options);

% Obtaining smoothed probabilities
[~, ~, smooth_prob] = estimatedprobyjoint(param,data);
smooth_p_1t = smooth_prob(:,1);
smooth_p_3t = smooth_prob(:,3);
smooth_p1_1t = smooth_p_1t + smooth_p_3t; % P(Sy1 = 1, Sy2 = 1) + P(Sy1 = 1, Sy2 = 2)

% Obtaining results
alpha_1_est = param(1);
alpha_2_est = param(2);
sigma1_est = exp(param(3));

p_11_est = exp(param(7))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_21_est = exp(param(8))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_31_est = exp(param(9))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_41_est = 1-p_11_est-p_21_est-p_31_est;
p_12_est = exp(param(10))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_22_est = exp(param(11))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_32_est = exp(param(12))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_42_est = 1-p_12_est-p_22_est-p_32_est;
p_13_est = exp(param(13))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_23_est = exp(param(14))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_33_est = exp(param(15))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_43_est = 1-p_13_est-p_23_est-p_33_est;
p_14_est = exp(param(16))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_24_est = exp(param(17))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_44_est = exp(param(18))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_34_est = 1-p_14_est-p_24_est-p_44_est;

P_est = [p_11_est p_12_est p_13_est p_14_est;
         p_21_est p_22_est p_23_est p_24_est;
         p_31_est p_32_est p_33_est p_34_est;
         p_41_est p_42_est p_43_est p_44_est];
     
% Obtaining unconditional probabilities
A_est = [eye(4)-P_est;ones(1,4)];
p_est_ = (A_est'*A_est)\A_est';
p_est = p_est_(:,5); % unconditional probabilities vector     

% Marginal transition probabilities [from Kim(2009)]
p1_11_est = (p_est(1)*(P_est(1,1)+P_est(3,1))+p_est(3)*(P_est(1,3)+P_est(3,3)))/(p_est(1)+p_est(3));
p1_22_est = (p_est(2)*(P_est(2,2)+P_est(4,2))+p_est(4)*(P_est(2,4)+P_est(4,4)))/(p_est(2)+p_est(4));

%% Calculating bias
bias_alpha_NDT = [alpha_1_est_NDT alpha_2_est_NDT sigma1_est_NDT] - [alpha sigma1];
bias_alpha_ND = [alpha_1_est_ND alpha_2_est_ND sigma1_est_ND] - [alpha sigma1];
bias_alpha = [alpha_1_est alpha_2_est sigma1_est] - [alpha sigma1];
bias_p_NDT = [p1_11_est_NDT p1_22_est_NDT] - [p1_11 p1_22];
bias_p_ND = [p1_11_est_ND p1_22_est_ND] - [p1_11 p1_22];
bias_p = [p1_11_est p1_22_est] - [p1_11 p1_22];
bias_p1_1t_NDT = smooth_p1_1t_NDT - p1_1t;
bias_p1_1t_ND = smooth_p1_1t_ND - p1_1t;
bias_p1_1t = smooth_p1_1t - p1_1t;