function correlation = correlationBernoulli(P)
% correlationBernoulli: Computes the correlation of two Bernoulli random
% variables given their joint transition probability matrix

% j = 1 <-- j1 = 1, j2 = 1
% j = 2 <-- j1 = 2, j2 = 1
% j = 3 <-- j1 = 1, j2 = 2
% j = 4 <-- j1 = 2, j2 = 2

A = [eye(4)-P;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5);

var1 = (p(1)+p(3))*(1-p(1)-p(3));
var2 = (p(1)+p(2))*(1-p(1)-p(2));
covariance = p(1)*p(4)-p(2)*p(3);

correlation = covariance/sqrt(var1*var2);

end

