%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function obtains the predction, filtered and smoothed probabilities
%
% Manuel Gonzalez-Astudillo
% 7/17/13
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [pred_prob, filter_prob, smooth_prob] = estimatedprob_depvarR(param,data)
%% Setting up parameters
paramm = param(1:26);
R_1 = exp(paramm(1));
R_2 = exp(paramm(2));
alphap_1 = exp(paramm(3));
alphap_2 = alphap_1 + exp(paramm(4));
alphay_1 = exp(paramm(5));
alphay_2 = alphay_1 + paramm(6);
kappaRp_1 = paramm(7);
kappaRp_2 = kappaRp_1 + paramm(8);
kappaRy_1 = paramm(9);
kappaRy_2 = kappaRy_1 + paramm(10);
rhoR_1 = exp(paramm(11))/(1+exp(paramm(11)));
rhoR_2 = exp(paramm(12))/(1+exp(paramm(12)));
sigmaR_1 = exp(paramm(13));
sigmaR_2 = sigmaR_1 + exp(paramm(14));
tau_1 = exp(paramm(15));
tau_2 = exp(paramm(16));
gammab_1 = paramm(17);
gammab_2 = gammab_1 + exp(paramm(18));
gammay_1 = exp(paramm(19));
gammay_2 = gammay_1 + paramm(20);
kappatauy_1 = paramm(21);
kappatauy_2 = kappatauy_1 + paramm(22);
rhotau_1 = exp(paramm(23))/(1+exp(paramm(23)));
rhotau_2 = exp(paramm(24))/(1+exp(paramm(24)));
sigmatau_1 = exp(paramm(25));
sigmatau_2 = sigmatau_1 + exp(paramm(26));

betaR_11 = [rhoR_1 (1-rhoR_1)*[R_1 alphap_1 alphay_1] sigmaR_1*kappaRp_1 sigmaR_1*kappaRy_1]';
betaR_12 = [rhoR_1 (1-rhoR_1)*[R_1 alphap_1 alphay_1] sigmaR_2*kappaRp_1 sigmaR_2*kappaRy_1]';
betaR_21 = [rhoR_2 (1-rhoR_2)*[R_2 alphap_2 alphay_2] sigmaR_1*kappaRp_2 sigmaR_1*kappaRy_2]';
betaR_22 = [rhoR_2 (1-rhoR_2)*[R_2 alphap_2 alphay_2] sigmaR_2*kappaRp_2 sigmaR_2*kappaRy_2]';
betatau_11 = [rhotau_1 (1-rhotau_1)*[tau_1 gammab_1 gammay_1] sigmatau_1*kappatauy_1]';
betatau_12 = [rhotau_1 (1-rhotau_1)*[tau_1 gammab_1 gammay_1] sigmatau_2*kappatauy_1]';
betatau_21 = [rhotau_2 (1-rhotau_2)*[tau_2 gammab_2 gammay_2] sigmatau_1*kappatauy_2]';
betatau_22 = [rhotau_2 (1-rhotau_2)*[tau_2 gammab_2 gammay_2] sigmatau_2*kappatauy_2]';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% S
% j = 1 <-- jmf = 1 (jm = 1, jf = 1), jsR = 1, jstau = 1
% j = 2 <-- jmf = 2 (jm = 2, jf = 1), jsR = 1, jstau = 1
% j = 3 <-- jmf = 3 (jm = 1, jf = 2), jsR = 1, jstau = 1
% j = 4 <-- jmf = 4 (jm = 2, jf = 2), jsR = 1, jstau = 1
% j = 5 <-- jmf = 1 (jm = 1, jf = 1), jsR = 2, jstau = 1
% j = 6 <-- jmf = 2 (jm = 2, jf = 1), jsR = 2, jstau = 1
% j = 7 <-- jmf = 3 (jm = 1, jf = 2), jsR = 2, jstau = 1
% j = 8 <-- jmf = 4 (jm = 2, jf = 2), jsR = 2, jstau = 1
% j = 9 <-- jmf = 1 (jm = 1, jf = 1), jsR = 1, jstau = 2
% j = 10 <-- jmf = 2 (jm = 2, jf = 1), jsR = 1, jstau = 2
% j = 11 <-- jmf = 3 (jm = 1, jf = 2), jsR = 1, jstau = 2
% j = 12 <-- jmf = 4 (jm = 2, jf = 2), jsR = 1, jstau = 2
% j = 13 <-- jmf = 1 (jm = 1, jf = 1), jsR = 2, jstau = 2
% j = 14 <-- jmf = 2 (jm = 2, jf = 1), jsR = 2, jstau = 2
% j = 15 <-- jmf = 3 (jm = 1, jf = 2), jsR = 2, jstau = 2
% j = 16 <-- jmf = 4 (jm = 2, jf = 2), jsR = 2, jstau = 2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
paramp1 = param(27:33);
p_11 = exp(paramp1(1))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_21 = exp(paramp1(2))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_31 = exp(paramp1(3))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_41 = exp(paramp1(4))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_51 = exp(paramp1(5))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_61 = exp(paramp1(6))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_71 = exp(paramp1(7))/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
p_81 = 1/(1+exp(paramp1(1))+exp(paramp1(2))+exp(paramp1(3))+exp(paramp1(4))+exp(paramp1(5))+exp(paramp1(6))+exp(paramp1(7)));
paramp2 = param(34:40);
p_12 = exp(paramp2(1))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_22 = exp(paramp2(2))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_32 = exp(paramp2(3))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_42 = exp(paramp2(4))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_52 = exp(paramp2(5))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_62 = exp(paramp2(6))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_72 = exp(paramp2(7))/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
p_82 = 1/(1+exp(paramp2(1))+exp(paramp2(2))+exp(paramp2(3))+exp(paramp2(4))+exp(paramp2(5))+exp(paramp2(6))+exp(paramp2(7)));
paramp3 = param(41:47);
p_13 = exp(paramp3(1))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_23 = exp(paramp3(2))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_33 = exp(paramp3(3))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_43 = exp(paramp3(4))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_53 = exp(paramp3(5))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_63 = exp(paramp3(6))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_73 = exp(paramp3(7))/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
p_83 = 1/(1+exp(paramp3(1))+exp(paramp3(2))+exp(paramp3(3))+exp(paramp3(4))+exp(paramp3(5))+exp(paramp3(6))+exp(paramp3(7)));
paramp4 = param(48:54);
p_14 = exp(paramp4(1))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_24 = exp(paramp4(2))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_34 = exp(paramp4(3))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_44 = exp(paramp4(4))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_54 = exp(paramp4(5))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_64 = exp(paramp4(6))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_74 = exp(paramp4(7))/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
p_84 = 1/(1+exp(paramp4(1))+exp(paramp4(2))+exp(paramp4(3))+exp(paramp4(4))+exp(paramp4(5))+exp(paramp4(6))+exp(paramp4(7)));
paramp5 = param(55:61);
p_15 = exp(paramp5(1))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_25 = exp(paramp5(2))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_35 = exp(paramp5(3))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_45 = exp(paramp5(4))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_55 = exp(paramp5(5))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_65 = exp(paramp5(6))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_75 = exp(paramp5(7))/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
p_85 = 1/(1+exp(paramp5(1))+exp(paramp5(2))+exp(paramp5(3))+exp(paramp5(4))+exp(paramp5(5))+exp(paramp5(6))+exp(paramp5(7)));
paramp6 = param(62:68);
p_16 = exp(paramp6(1))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_26 = exp(paramp6(2))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_36 = exp(paramp6(3))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_46 = exp(paramp6(4))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_56 = exp(paramp6(5))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_66 = exp(paramp6(6))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_76 = exp(paramp6(7))/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
p_86 = 1/(1+exp(paramp6(1))+exp(paramp6(2))+exp(paramp6(3))+exp(paramp6(4))+exp(paramp6(5))+exp(paramp6(6))+exp(paramp6(7)));
paramp7 = param(69:75);
p_17 = exp(paramp7(1))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_27 = exp(paramp7(2))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_37 = exp(paramp7(3))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_47 = exp(paramp7(4))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_57 = exp(paramp7(5))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_67 = exp(paramp7(6))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_77 = exp(paramp7(7))/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
p_87 = 1/(1+exp(paramp7(1))+exp(paramp7(2))+exp(paramp7(3))+exp(paramp7(4))+exp(paramp7(5))+exp(paramp7(6))+exp(paramp7(7)));
paramp8 = param(76:82);
p_18 = exp(paramp8(1))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_28 = exp(paramp8(2))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_38 = exp(paramp8(3))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_48 = exp(paramp8(4))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_58 = exp(paramp8(5))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_68 = exp(paramp8(6))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_78 = exp(paramp8(7))/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));
p_88 = 1/(1+exp(paramp8(1))+exp(paramp8(2))+exp(paramp8(3))+exp(paramp8(4))+exp(paramp8(5))+exp(paramp8(6))+exp(paramp8(7)));

% Transition probability matrix of Sm, Sf and SsR
PSmfsR = [p_11	p_12	p_13	p_14	p_15	p_16	p_17	p_18;
          p_21	p_22	p_23	p_24	p_25	p_26	p_27	p_28;
          p_31	p_32	p_33	p_34	p_35	p_36	p_37	p_38;
          p_41	p_42	p_43	p_44	p_45	p_46	p_47	p_48;
          p_51	p_52	p_53	p_54	p_55	p_56	p_57	p_58;
          p_61	p_62	p_63	p_64	p_65	p_66	p_67	p_68;
          p_71	p_72	p_73	p_74	p_75	p_76	p_77	p_78;
          p_81	p_82	p_83	p_84	p_85	p_86	p_87	p_88];
 
% Transition Probability matrix variance of tau
pstau_11 = exp(param(83))/(1+exp(param(83)));
pstau_21 = 1/(1+exp(param(83)));
pstau_12 = exp(param(84))/(1+exp(param(84)));
pstau_22 = 1/(1+exp(param(84)));
PSstau = [pstau_11 pstau_12;
          pstau_21 pstau_22];
   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% [ pmf_11*psR_11*pstau_11, pmf_12*psR_11*pstau_11, pmf_13*psR_11*pstau_11, pmf_14*psR_11*pstau_11, pmf_11*psR_12*pstau_11, pmf_12*psR_12*pstau_11, pmf_13*psR_12*pstau_11, pmf_14*psR_12*pstau_11, pmf_11*psR_11*pstau_12, pmf_12*psR_11*pstau_12, pmf_13*psR_11*pstau_12, pmf_14*psR_11*pstau_12, pmf_11*psR_12*pstau_12, pmf_12*psR_12*pstau_12, pmf_13*psR_12*pstau_12, pmf_14*psR_12*pstau_12]
% [ pmf_21*psR_11*pstau_11, pmf_22*psR_11*pstau_11, pmf_23*psR_11*pstau_11, pmf_24*psR_11*pstau_11, pmf_21*psR_12*pstau_11, pmf_22*psR_12*pstau_11, pmf_23*psR_12*pstau_11, pmf_24*psR_12*pstau_11, pmf_21*psR_11*pstau_12, pmf_22*psR_11*pstau_12, pmf_23*psR_11*pstau_12, pmf_24*psR_11*pstau_12, pmf_21*psR_12*pstau_12, pmf_22*psR_12*pstau_12, pmf_23*psR_12*pstau_12, pmf_24*psR_12*pstau_12]
% [ pmf_31*psR_11*pstau_11, pmf_32*psR_11*pstau_11, pmf_33*psR_11*pstau_11, pmf_34*psR_11*pstau_11, pmf_31*psR_12*pstau_11, pmf_32*psR_12*pstau_11, pmf_33*psR_12*pstau_11, pmf_34*psR_12*pstau_11, pmf_31*psR_11*pstau_12, pmf_32*psR_11*pstau_12, pmf_33*psR_11*pstau_12, pmf_34*psR_11*pstau_12, pmf_31*psR_12*pstau_12, pmf_32*psR_12*pstau_12, pmf_33*psR_12*pstau_12, pmf_34*psR_12*pstau_12]
% [ pmf_41*psR_11*pstau_11, pmf_42*psR_11*pstau_11, pmf_43*psR_11*pstau_11, pmf_44*psR_11*pstau_11, pmf_41*psR_12*pstau_11, pmf_42*psR_12*pstau_11, pmf_43*psR_12*pstau_11, pmf_44*psR_12*pstau_11, pmf_41*psR_11*pstau_12, pmf_42*psR_11*pstau_12, pmf_43*psR_11*pstau_12, pmf_44*psR_11*pstau_12, pmf_41*psR_12*pstau_12, pmf_42*psR_12*pstau_12, pmf_43*psR_12*pstau_12, pmf_44*psR_12*pstau_12]
% [ pmf_11*psR_21*pstau_11, pmf_12*psR_21*pstau_11, pmf_13*psR_21*pstau_11, pmf_14*psR_21*pstau_11, pmf_11*psR_22*pstau_11, pmf_12*psR_22*pstau_11, pmf_13*psR_22*pstau_11, pmf_14*psR_22*pstau_11, pmf_11*psR_21*pstau_12, pmf_12*psR_21*pstau_12, pmf_13*psR_21*pstau_12, pmf_14*psR_21*pstau_12, pmf_11*psR_22*pstau_12, pmf_12*psR_22*pstau_12, pmf_13*psR_22*pstau_12, pmf_14*psR_22*pstau_12]
% [ pmf_21*psR_21*pstau_11, pmf_22*psR_21*pstau_11, pmf_23*psR_21*pstau_11, pmf_24*psR_21*pstau_11, pmf_21*psR_22*pstau_11, pmf_22*psR_22*pstau_11, pmf_23*psR_22*pstau_11, pmf_24*psR_22*pstau_11, pmf_21*psR_21*pstau_12, pmf_22*psR_21*pstau_12, pmf_23*psR_21*pstau_12, pmf_24*psR_21*pstau_12, pmf_21*psR_22*pstau_12, pmf_22*psR_22*pstau_12, pmf_23*psR_22*pstau_12, pmf_24*psR_22*pstau_12]
% [ pmf_31*psR_21*pstau_11, pmf_32*psR_21*pstau_11, pmf_33*psR_21*pstau_11, pmf_34*psR_21*pstau_11, pmf_31*psR_22*pstau_11, pmf_32*psR_22*pstau_11, pmf_33*psR_22*pstau_11, pmf_34*psR_22*pstau_11, pmf_31*psR_21*pstau_12, pmf_32*psR_21*pstau_12, pmf_33*psR_21*pstau_12, pmf_34*psR_21*pstau_12, pmf_31*psR_22*pstau_12, pmf_32*psR_22*pstau_12, pmf_33*psR_22*pstau_12, pmf_34*psR_22*pstau_12]
% [ pmf_41*psR_21*pstau_11, pmf_42*psR_21*pstau_11, pmf_43*psR_21*pstau_11, pmf_44*psR_21*pstau_11, pmf_41*psR_22*pstau_11, pmf_42*psR_22*pstau_11, pmf_43*psR_22*pstau_11, pmf_44*psR_22*pstau_11, pmf_41*psR_21*pstau_12, pmf_42*psR_21*pstau_12, pmf_43*psR_21*pstau_12, pmf_44*psR_21*pstau_12, pmf_41*psR_22*pstau_12, pmf_42*psR_22*pstau_12, pmf_43*psR_22*pstau_12, pmf_44*psR_22*pstau_12]
% [ pmf_11*psR_11*pstau_21, pmf_12*psR_11*pstau_21, pmf_13*psR_11*pstau_21, pmf_14*psR_11*pstau_21, pmf_11*psR_12*pstau_21, pmf_12*psR_12*pstau_21, pmf_13*psR_12*pstau_21, pmf_14*psR_12*pstau_21, pmf_11*psR_11*pstau_22, pmf_12*psR_11*pstau_22, pmf_13*psR_11*pstau_22, pmf_14*psR_11*pstau_22, pmf_11*psR_12*pstau_22, pmf_12*psR_12*pstau_22, pmf_13*psR_12*pstau_22, pmf_14*psR_12*pstau_22]
% [ pmf_21*psR_11*pstau_21, pmf_22*psR_11*pstau_21, pmf_23*psR_11*pstau_21, pmf_24*psR_11*pstau_21, pmf_21*psR_12*pstau_21, pmf_22*psR_12*pstau_21, pmf_23*psR_12*pstau_21, pmf_24*psR_12*pstau_21, pmf_21*psR_11*pstau_22, pmf_22*psR_11*pstau_22, pmf_23*psR_11*pstau_22, pmf_24*psR_11*pstau_22, pmf_21*psR_12*pstau_22, pmf_22*psR_12*pstau_22, pmf_23*psR_12*pstau_22, pmf_24*psR_12*pstau_22]
% [ pmf_31*psR_11*pstau_21, pmf_32*psR_11*pstau_21, pmf_33*psR_11*pstau_21, pmf_34*psR_11*pstau_21, pmf_31*psR_12*pstau_21, pmf_32*psR_12*pstau_21, pmf_33*psR_12*pstau_21, pmf_34*psR_12*pstau_21, pmf_31*psR_11*pstau_22, pmf_32*psR_11*pstau_22, pmf_33*psR_11*pstau_22, pmf_34*psR_11*pstau_22, pmf_31*psR_12*pstau_22, pmf_32*psR_12*pstau_22, pmf_33*psR_12*pstau_22, pmf_34*psR_12*pstau_22]
% [ pmf_41*psR_11*pstau_21, pmf_42*psR_11*pstau_21, pmf_43*psR_11*pstau_21, pmf_44*psR_11*pstau_21, pmf_41*psR_12*pstau_21, pmf_42*psR_12*pstau_21, pmf_43*psR_12*pstau_21, pmf_44*psR_12*pstau_21, pmf_41*psR_11*pstau_22, pmf_42*psR_11*pstau_22, pmf_43*psR_11*pstau_22, pmf_44*psR_11*pstau_22, pmf_41*psR_12*pstau_22, pmf_42*psR_12*pstau_22, pmf_43*psR_12*pstau_22, pmf_44*psR_12*pstau_22]
% [ pmf_11*psR_21*pstau_21, pmf_12*psR_21*pstau_21, pmf_13*psR_21*pstau_21, pmf_14*psR_21*pstau_21, pmf_11*psR_22*pstau_21, pmf_12*psR_22*pstau_21, pmf_13*psR_22*pstau_21, pmf_14*psR_22*pstau_21, pmf_11*psR_21*pstau_22, pmf_12*psR_21*pstau_22, pmf_13*psR_21*pstau_22, pmf_14*psR_21*pstau_22, pmf_11*psR_22*pstau_22, pmf_12*psR_22*pstau_22, pmf_13*psR_22*pstau_22, pmf_14*psR_22*pstau_22]
% [ pmf_21*psR_21*pstau_21, pmf_22*psR_21*pstau_21, pmf_23*psR_21*pstau_21, pmf_24*psR_21*pstau_21, pmf_21*psR_22*pstau_21, pmf_22*psR_22*pstau_21, pmf_23*psR_22*pstau_21, pmf_24*psR_22*pstau_21, pmf_21*psR_21*pstau_22, pmf_22*psR_21*pstau_22, pmf_23*psR_21*pstau_22, pmf_24*psR_21*pstau_22, pmf_21*psR_22*pstau_22, pmf_22*psR_22*pstau_22, pmf_23*psR_22*pstau_22, pmf_24*psR_22*pstau_22]
% [ pmf_31*psR_21*pstau_21, pmf_32*psR_21*pstau_21, pmf_33*psR_21*pstau_21, pmf_34*psR_21*pstau_21, pmf_31*psR_22*pstau_21, pmf_32*psR_22*pstau_21, pmf_33*psR_22*pstau_21, pmf_34*psR_22*pstau_21, pmf_31*psR_21*pstau_22, pmf_32*psR_21*pstau_22, pmf_33*psR_21*pstau_22, pmf_34*psR_21*pstau_22, pmf_31*psR_22*pstau_22, pmf_32*psR_22*pstau_22, pmf_33*psR_22*pstau_22, pmf_34*psR_22*pstau_22]
% [ pmf_41*psR_21*pstau_21, pmf_42*psR_21*pstau_21, pmf_43*psR_21*pstau_21, pmf_44*psR_21*pstau_21, pmf_41*psR_22*pstau_21, pmf_42*psR_22*pstau_21, pmf_43*psR_22*pstau_21, pmf_44*psR_22*pstau_21, pmf_41*psR_21*pstau_22, pmf_42*psR_21*pstau_22, pmf_43*psR_21*pstau_22, pmf_44*psR_21*pstau_22, pmf_41*psR_22*pstau_22, pmf_42*psR_22*pstau_22, pmf_43*psR_22*pstau_22, pmf_44*psR_22*pstau_22]

% Global Transition Probability Matrix
P = kron(PSstau,PSmfsR);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
A = [eye(16)-P;ones(1,16)];
p_ = (A'*A)\A';
p = p_(:,17); % unconditional probabilities vector

T = length(data);
%% Setting up data
% data = [R_t tau_t p_t y_t b_{t-1} v_p v_y]
R = data(2:T,1);
dzlb = (R==0.25); % Dummy ZLB
tau = data(2:T,2);
xR = [data(1:T-1,1) ones(T-1,1) data(2:T,3:4) data(2:T,6:7)];
xtau = [data(1:T-1,2) ones(T-1,1) data(2:T,5) data(2:T,4) data(2:T,7)];

T = length(R);

%% Obtaining prediction and filtered probabilities
pred_p_1 = [p(1);zeros(T,1)];
pred_p_2 = [p(2);zeros(T,1)];
pred_p_3 = [p(3);zeros(T,1)];
pred_p_4 = [p(4);zeros(T,1)];
pred_p_5 = [p(5);zeros(T,1)];
pred_p_6 = [p(6);zeros(T,1)];
pred_p_7 = [p(7);zeros(T,1)];
pred_p_8 = [p(8);zeros(T,1)];
pred_p_9 = [p(9);zeros(T,1)];
pred_p_10 = [p(10);zeros(T,1)];
pred_p_11 = [p(11);zeros(T,1)];
pred_p_12 = [p(12);zeros(T,1)];
pred_p_13 = [p(13);zeros(T,1)];
pred_p_14 = [p(14);zeros(T,1)];
pred_p_15 = [p(15);zeros(T,1)];
pred_p_16 = [p(16);zeros(T,1)];
filter_p_1 = zeros(T,1);
filter_p_2 = zeros(T,1);
filter_p_3 = zeros(T,1);
filter_p_4 = zeros(T,1);
filter_p_5 = zeros(T,1);
filter_p_6 = zeros(T,1);
filter_p_7 = zeros(T,1);
filter_p_8 = zeros(T,1);
filter_p_9 = zeros(T,1);
filter_p_10 = zeros(T,1);
filter_p_11 = zeros(T,1);
filter_p_12 = zeros(T,1);
filter_p_13 = zeros(T,1);
filter_p_14 = zeros(T,1);
filter_p_15 = zeros(T,1);
filter_p_16 = zeros(T,1);
% Densities conditional on state
fR11 = ((normpdf(R,xR*betaR_11,sigmaR_1)).^(1-dzlb)).*((1-normcdf(xR*betaR_11-0.25,0,sigmaR_1)).^dzlb); % density for R conditional on betaR_1 and sigma_1
fR21 = ((normpdf(R,xR*betaR_21,sigmaR_1)).^(1-dzlb)).*((1-normcdf(xR*betaR_21-0.25,0,sigmaR_1)).^dzlb); % density for R conditional on betaR_1 and sigma_2
fR12 = ((normpdf(R,xR*betaR_12,sigmaR_2)).^(1-dzlb)).*((1-normcdf(xR*betaR_12-0.25,0,sigmaR_2)).^dzlb); % density for R conditional on betaR_2 and sigma_1
fR22 = ((normpdf(R,xR*betaR_22,sigmaR_2)).^(1-dzlb)).*((1-normcdf(xR*betaR_22-0.25,0,sigmaR_2)).^dzlb); % density for R conditional on betaR_2 and sigma_2
ftau11 = normpdf(tau,xtau*betatau_11,sigmatau_1); % density for tau conditional on betatau_1 sigmatau_1
ftau21 = normpdf(tau,xtau*betatau_21,sigmatau_1); % density for tau conditional on betatau_2 sigmatau_1
ftau12 = normpdf(tau,xtau*betatau_12,sigmatau_2); % density for tau conditional on betatau_1 sigmatau_2
ftau22 = normpdf(tau,xtau*betatau_22,sigmatau_2); % density for tau conditional on betatau_2 sigmatau_2
for t = 1:T
    fy = pred_p_1(t)*fR11(t)*ftau11(t) + pred_p_2(t)*fR21(t)*ftau11(t) + pred_p_3(t)*fR11(t)*ftau21(t) + pred_p_4(t)*fR21(t)*ftau21(t) +...
         pred_p_5(t)*fR12(t)*ftau11(t) + pred_p_6(t)*fR22(t)*ftau11(t) + pred_p_7(t)*fR12(t)*ftau21(t) + pred_p_8(t)*fR22(t)*ftau21(t) +...
         pred_p_9(t)*fR11(t)*ftau12(t) + pred_p_10(t)*fR21(t)*ftau12(t) + pred_p_11(t)*fR11(t)*ftau22(t) + pred_p_12(t)*fR21(t)*ftau22(t) +...
         pred_p_13(t)*fR12(t)*ftau12(t) + pred_p_14(t)*fR22(t)*ftau12(t) + pred_p_15(t)*fR12(t)*ftau22(t) + pred_p_16(t)*fR22(t)*ftau22(t); % joint density integrated over states
    filter_p_1(t) = pred_p_1(t)*fR11(t)*ftau11(t)/fy; % filtered probability state 1
    filter_p_2(t) = pred_p_2(t)*fR21(t)*ftau11(t)/fy; % filtered probability state 2
    filter_p_3(t) = pred_p_3(t)*fR11(t)*ftau21(t)/fy; % filtered probability state 3
    filter_p_4(t) = pred_p_4(t)*fR21(t)*ftau21(t)/fy; % filtered probability state 4
    filter_p_5(t) = pred_p_5(t)*fR12(t)*ftau11(t)/fy; % filtered probability state 5
    filter_p_6(t) = pred_p_6(t)*fR22(t)*ftau11(t)/fy; % filtered probability state 6
    filter_p_7(t) = pred_p_7(t)*fR12(t)*ftau21(t)/fy; % filtered probability state 7
    filter_p_8(t) = pred_p_8(t)*fR22(t)*ftau21(t)/fy; % filtered probability state 8
    filter_p_9(t) = pred_p_9(t)*fR11(t)*ftau12(t)/fy; % filtered probability state 9
    filter_p_10(t) = pred_p_10(t)*fR21(t)*ftau12(t)/fy; % filtered probability state 10
    filter_p_11(t) = pred_p_11(t)*fR11(t)*ftau22(t)/fy; % filtered probability state 11
    filter_p_12(t) = pred_p_12(t)*fR21(t)*ftau22(t)/fy; % filtered probability state 12
    filter_p_13(t) = pred_p_13(t)*fR12(t)*ftau12(t)/fy; % filtered probability state 13
    filter_p_14(t) = pred_p_14(t)*fR22(t)*ftau12(t)/fy; % filtered probability state 14
    filter_p_15(t) = pred_p_15(t)*fR12(t)*ftau22(t)/fy; % filtered probability state 15
    filter_p_16(t) = pred_p_16(t)*fR22(t)*ftau22(t)/fy; % filtered probability state 16
    filter_pt = [filter_p_1(t);filter_p_2(t);filter_p_3(t);filter_p_4(t);...
                 filter_p_5(t);filter_p_6(t);filter_p_7(t);filter_p_8(t);...
                 filter_p_9(t);filter_p_10(t);filter_p_11(t);filter_p_12(t);...
                 filter_p_13(t);filter_p_14(t);filter_p_15(t);filter_p_16(t)];
    pred_p_1(t+1) = P(1,:)*filter_pt; % prediction probability state 1
    pred_p_2(t+1) = P(2,:)*filter_pt; % prediction probability state 2
    pred_p_3(t+1) = P(3,:)*filter_pt; % prediction probability state 3
    pred_p_4(t+1) = P(4,:)*filter_pt; % prediction probability state 4
    pred_p_5(t+1) = P(5,:)*filter_pt; % prediction probability state 5
    pred_p_6(t+1) = P(6,:)*filter_pt; % prediction probability state 6
    pred_p_7(t+1) = P(7,:)*filter_pt; % prediction probability state 7
    pred_p_8(t+1) = P(8,:)*filter_pt; % prediction probability state 8
    pred_p_9(t+1) = P(9,:)*filter_pt; % prediction probability state 9
    pred_p_10(t+1) = P(10,:)*filter_pt; % prediction probability state 10
    pred_p_11(t+1) = P(11,:)*filter_pt; % prediction probability state 11
    pred_p_12(t+1) = P(12,:)*filter_pt; % prediction probability state 12
    pred_p_13(t+1) = P(13,:)*filter_pt; % prediction probability state 13
    pred_p_14(t+1) = P(14,:)*filter_pt; % prediction probability state 14
    pred_p_15(t+1) = P(15,:)*filter_pt; % prediction probability state 15
    pred_p_16(t+1) = P(16,:)*filter_pt; % prediction probability state 16
end;

pred_prob = [pred_p_1 pred_p_2 pred_p_3 pred_p_4 pred_p_5 pred_p_6 pred_p_7 pred_p_8 pred_p_9 pred_p_10 pred_p_11 pred_p_12 pred_p_13 pred_p_14 pred_p_15 pred_p_16];
filter_prob = [filter_p_1 filter_p_2 filter_p_3 filter_p_4 filter_p_5 filter_p_6 filter_p_7 filter_p_8 filter_p_9 filter_p_10 filter_p_11 filter_p_12 filter_p_13 filter_p_14 filter_p_15 filter_p_16];

%% Obtaining smoothed probabilities [Kim (1994)]
smooth_p_1 = [zeros(T-1,1);filter_p_1(T)];
smooth_p_2 = [zeros(T-1,1);filter_p_2(T)];
smooth_p_3 = [zeros(T-1,1);filter_p_3(T)];
smooth_p_4 = [zeros(T-1,1);filter_p_4(T)];
smooth_p_5 = [zeros(T-1,1);filter_p_5(T)];
smooth_p_6 = [zeros(T-1,1);filter_p_6(T)];
smooth_p_7 = [zeros(T-1,1);filter_p_7(T)];
smooth_p_8 = [zeros(T-1,1);filter_p_8(T)];
smooth_p_9 = [zeros(T-1,1);filter_p_9(T)];
smooth_p_10 = [zeros(T-1,1);filter_p_10(T)];
smooth_p_11 = [zeros(T-1,1);filter_p_11(T)];
smooth_p_12 = [zeros(T-1,1);filter_p_12(T)];
smooth_p_13 = [zeros(T-1,1);filter_p_13(T)];
smooth_p_14 = [zeros(T-1,1);filter_p_14(T)];
smooth_p_15 = [zeros(T-1,1);filter_p_15(T)];
smooth_p_16 = [zeros(T-1,1);filter_p_16(T)];
for t = T-1:-1:1
    auxiliarvector = [smooth_p_1(t+1)/pred_p_1(t+1); smooth_p_2(t+1)/pred_p_2(t+1); smooth_p_3(t+1)/pred_p_3(t+1); smooth_p_4(t+1)/pred_p_4(t+1);...
                      smooth_p_5(t+1)/pred_p_5(t+1); smooth_p_6(t+1)/pred_p_6(t+1); smooth_p_7(t+1)/pred_p_7(t+1); smooth_p_8(t+1)/pred_p_8(t+1);...
                      smooth_p_9(t+1)/pred_p_9(t+1); smooth_p_10(t+1)/pred_p_10(t+1); smooth_p_11(t+1)/pred_p_11(t+1); smooth_p_12(t+1)/pred_p_12(t+1);...
                      smooth_p_13(t+1)/pred_p_13(t+1); smooth_p_14(t+1)/pred_p_14(t+1); smooth_p_15(t+1)/pred_p_15(t+1); smooth_p_16(t+1)/pred_p_16(t+1)];
    smooth_p_1(t) = filter_p_1(t)*(P(:,1)'*auxiliarvector);
    smooth_p_2(t) = filter_p_2(t)*(P(:,2)'*auxiliarvector);
    smooth_p_3(t) = filter_p_3(t)*(P(:,3)'*auxiliarvector);
    smooth_p_4(t) = filter_p_4(t)*(P(:,4)'*auxiliarvector);
    smooth_p_5(t) = filter_p_5(t)*(P(:,5)'*auxiliarvector);
    smooth_p_6(t) = filter_p_6(t)*(P(:,6)'*auxiliarvector);
    smooth_p_7(t) = filter_p_7(t)*(P(:,7)'*auxiliarvector);
    smooth_p_8(t) = filter_p_8(t)*(P(:,8)'*auxiliarvector);
    smooth_p_9(t) = filter_p_9(t)*(P(:,9)'*auxiliarvector);
    smooth_p_10(t) = filter_p_10(t)*(P(:,10)'*auxiliarvector);
    smooth_p_11(t) = filter_p_11(t)*(P(:,11)'*auxiliarvector);
    smooth_p_12(t) = filter_p_12(t)*(P(:,12)'*auxiliarvector);
    smooth_p_13(t) = filter_p_13(t)*(P(:,13)'*auxiliarvector);
    smooth_p_14(t) = filter_p_14(t)*(P(:,14)'*auxiliarvector);
    smooth_p_15(t) = filter_p_15(t)*(P(:,15)'*auxiliarvector);
    smooth_p_16(t) = filter_p_16(t)*(P(:,16)'*auxiliarvector);
end;

smooth_prob = [smooth_p_1 smooth_p_2 smooth_p_3 smooth_p_4 smooth_p_5 smooth_p_6 smooth_p_7 smooth_p_8 smooth_p_9 smooth_p_10 smooth_p_11 smooth_p_12 smooth_p_13 smooth_p_14 smooth_p_15 smooth_p_16];
