%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function obtains the predction, filtered and smoothed probabilities
%
% Manuel Gonzalez-Astudillo
% 7/17/13
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [pred_prob, filter_prob, smooth_prob] = estimatedprobfixedrhoint(param,data)

%% Setting up parameters
paramm = param(1:22);
R_c = exp(paramm(1));
alphap_1 = exp(paramm(2));
alphap_2 = alphap_1 + exp(paramm(3));
alphay_1 = exp(paramm(4));
alphay_2 = alphay_1 + paramm(5);
kappaRp_1 = paramm(6);
kappaRp_2 = kappaRp_1 + paramm(7);
kappaRy_1 = paramm(8);
kappaRy_2 = kappaRy_1 + paramm(9);
rhoR = exp(paramm(10))/(1+exp(paramm(10)));
sigmaR_1 = exp(paramm(11));
sigmaR_2 = sigmaR_1 + exp(paramm(12));
tau_c = exp(paramm(13));
gammab_1 = paramm(14);
gammab_2 = gammab_1 + exp(paramm(15));
gammay_1 = exp(paramm(16));
gammay_2 = gammay_1 + paramm(17);
kappatauy_1 = paramm(18);
kappatauy_2 = kappatauy_1 + paramm(19);
rhotau = exp(paramm(20))/(1+exp(paramm(20)));
sigmatau_1 = exp(paramm(21));
sigmatau_2 = sigmatau_1 + exp(paramm(22));

betaR_11 = [rhoR (1-rhoR)*[R_c alphap_1 alphay_1] sigmaR_1*kappaRp_1 sigmaR_1*kappaRy_1]';
betaR_12 = [rhoR (1-rhoR)*[R_c alphap_1 alphay_1] sigmaR_2*kappaRp_1 sigmaR_2*kappaRy_1]';
betaR_21 = [rhoR (1-rhoR)*[R_c alphap_2 alphay_2] sigmaR_1*kappaRp_2 sigmaR_1*kappaRy_2]';
betaR_22 = [rhoR (1-rhoR)*[R_c alphap_2 alphay_2] sigmaR_2*kappaRp_2 sigmaR_2*kappaRy_2]';
betatau_11 = [rhotau (1-rhotau)*[tau_c gammab_1 gammay_1] sigmatau_1*kappatauy_1]';
betatau_12 = [rhotau (1-rhotau)*[tau_c gammab_1 gammay_1] sigmatau_2*kappatauy_1]';
betatau_21 = [rhotau (1-rhotau)*[tau_c gammab_2 gammay_2] sigmatau_1*kappatauy_2]';
betatau_22 = [rhotau (1-rhotau)*[tau_c gammab_2 gammay_2] sigmatau_2*kappatauy_2]';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Smf
% jmf = 1 <-- jm = 1, jf = 1;
% jmf = 2 <-- jm = 2, jf = 1;
% jmf = 3 <-- jm = 1, jf = 2;
% jmf = 4 <-- jm = 2, jf = 2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
paramp = param(23:38);
pmf_11 = exp(paramp(1))/(1+exp(paramp(1))+exp(paramp(2))+exp(paramp(3)));
pmf_21 = exp(paramp(2))/(1+exp(paramp(1))+exp(paramp(2))+exp(paramp(3)));
pmf_31 = exp(paramp(3))/(1+exp(paramp(1))+exp(paramp(2))+exp(paramp(3)));
pmf_41 = 1/(1+exp(paramp(1))+exp(paramp(2))+exp(paramp(3)));
pmf_12 = exp(paramp(4))/(1+exp(paramp(4))+exp(paramp(5))+exp(paramp(6)));
pmf_22 = exp(paramp(5))/(1+exp(paramp(4))+exp(paramp(5))+exp(paramp(6)));
pmf_32 = exp(paramp(6))/(1+exp(paramp(4))+exp(paramp(5))+exp(paramp(6)));
pmf_42 = 1/(1+exp(paramp(4))+exp(paramp(5))+exp(paramp(6)));
pmf_13 = exp(paramp(7))/(1+exp(paramp(7))+exp(paramp(8))+exp(paramp(9)));
pmf_23 = exp(paramp(8))/(1+exp(paramp(7))+exp(paramp(8))+exp(paramp(9)));
pmf_33 = exp(paramp(9))/(1+exp(paramp(7))+exp(paramp(8))+exp(paramp(9)));
pmf_43 = 1/(1+exp(paramp(7))+exp(paramp(8))+exp(paramp(9)));
pmf_14 = exp(paramp(10))/(1+exp(paramp(10))+exp(paramp(11))+exp(paramp(12)));
pmf_24 = exp(paramp(11))/(1+exp(paramp(10))+exp(paramp(11))+exp(paramp(12)));
pmf_34 = exp(paramp(12))/(1+exp(paramp(10))+exp(paramp(11))+exp(paramp(12)));
pmf_44 = 1/(1+exp(paramp(10))+exp(paramp(11))+exp(paramp(12)));

PSmf = [pmf_11 pmf_12 pmf_13 pmf_14;
        pmf_21 pmf_22 pmf_23 pmf_24;
        pmf_31 pmf_32 pmf_33 pmf_34;
        pmf_41 pmf_42 pmf_43 pmf_44];

% Transition Probabilities for standard deviation of R
psR_11 = exp(paramp(13))/(1+exp(paramp(13)));
psR_21 = 1/(1+exp(paramp(13)));
psR_12 = exp(paramp(14))/(1+exp(paramp(14)));
psR_22 = 1/(1+exp(paramp(14)));

PsR = [psR_11 psR_12;
       psR_21 psR_22];
   
% Transition Probabilities for standard deviation of tau
pstau_11 = exp(paramp(15))/(1+exp(paramp(15)));
pstau_21 = 1/(1+exp(paramp(15)));
pstau_12 = exp(paramp(16))/(1+exp(paramp(16)));
pstau_22 = 1/(1+exp(paramp(16)));

Pstau = [pstau_11 pstau_12;
         pstau_21 pstau_22];
   
% Global Transition Probability Matrix
P = kron(Pstau,kron(PsR,PSmf));

A = [eye(16)-P;ones(1,16)];
p_ = (A'*A)\A';
p = p_(:,17); % unconditional probabilities vector

T = size(data,1);

%% Setting up data
% data = [R_t tau_t p_t y_t b_{t-1} v_p v_y]
R = data(2:T,1);
dzlb = (R==0.25); % Dummy ZLB
tau = data(2:T,2);
xR = [data(1:T-1,1) ones(T-1,1) data(2:T,3:4) data(2:T,6:7)];
xtau = [data(1:T-1,2) ones(T-1,1) data(2:T,5) data(2:T,4) data(2:T,7)];

T = length(R);

%% Obtaining prediction and filtered probabilities
pred_p_1 = [p(1);zeros(T,1)];
pred_p_2 = [p(2);zeros(T,1)];
pred_p_3 = [p(3);zeros(T,1)];
pred_p_4 = [p(4);zeros(T,1)];
pred_p_5 = [p(5);zeros(T,1)];
pred_p_6 = [p(6);zeros(T,1)];
pred_p_7 = [p(7);zeros(T,1)];
pred_p_8 = [p(8);zeros(T,1)];
pred_p_9 = [p(9);zeros(T,1)];
pred_p_10 = [p(10);zeros(T,1)];
pred_p_11 = [p(11);zeros(T,1)];
pred_p_12 = [p(12);zeros(T,1)];
pred_p_13 = [p(13);zeros(T,1)];
pred_p_14 = [p(14);zeros(T,1)];
pred_p_15 = [p(15);zeros(T,1)];
pred_p_16 = [p(16);zeros(T,1)];
filter_p_1 = zeros(T,1);
filter_p_2 = zeros(T,1);
filter_p_3 = zeros(T,1);
filter_p_4 = zeros(T,1);
filter_p_5 = zeros(T,1);
filter_p_6 = zeros(T,1);
filter_p_7 = zeros(T,1);
filter_p_8 = zeros(T,1);
filter_p_9 = zeros(T,1);
filter_p_10 = zeros(T,1);
filter_p_11 = zeros(T,1);
filter_p_12 = zeros(T,1);
filter_p_13 = zeros(T,1);
filter_p_14 = zeros(T,1);
filter_p_15 = zeros(T,1);
filter_p_16 = zeros(T,1);
% Densities conditional on state
fR11 = ((normpdf(R,xR*betaR_11,sigmaR_1)).^(1-dzlb)).*((1-normcdf(xR*betaR_11-0.25,0,sigmaR_1)).^dzlb); % density for R conditional on betaR_1 and sigma_1
fR21 = ((normpdf(R,xR*betaR_21,sigmaR_1)).^(1-dzlb)).*((1-normcdf(xR*betaR_21-0.25,0,sigmaR_1)).^dzlb); % density for R conditional on betaR_1 and sigma_2
fR12 = ((normpdf(R,xR*betaR_12,sigmaR_2)).^(1-dzlb)).*((1-normcdf(xR*betaR_12-0.25,0,sigmaR_2)).^dzlb); % density for R conditional on betaR_2 and sigma_1
fR22 = ((normpdf(R,xR*betaR_22,sigmaR_2)).^(1-dzlb)).*((1-normcdf(xR*betaR_22-0.25,0,sigmaR_2)).^dzlb); % density for R conditional on betaR_2 and sigma_2
ftau11 = normpdf(tau,xtau*betatau_11,sigmatau_1); % density for tau conditional on betatau_1 sigmatau_1
ftau21 = normpdf(tau,xtau*betatau_21,sigmatau_1); % density for tau conditional on betatau_2 sigmatau_1
ftau12 = normpdf(tau,xtau*betatau_12,sigmatau_2); % density for tau conditional on betatau_1 sigmatau_2
ftau22 = normpdf(tau,xtau*betatau_22,sigmatau_2); % density for tau conditional on betatau_2 sigmatau_2
for t = 1:T
    fy = pred_p_1(t)*fR11(t)*ftau11(t) + pred_p_2(t)*fR21(t)*ftau11(t) + pred_p_3(t)*fR11(t)*ftau21(t) + pred_p_4(t)*fR21(t)*ftau21(t) +...
         pred_p_5(t)*fR12(t)*ftau11(t) + pred_p_6(t)*fR22(t)*ftau11(t) + pred_p_7(t)*fR12(t)*ftau21(t) + pred_p_8(t)*fR22(t)*ftau21(t) +...
         pred_p_9(t)*fR11(t)*ftau12(t) + pred_p_10(t)*fR21(t)*ftau12(t) + pred_p_11(t)*fR11(t)*ftau22(t) + pred_p_12(t)*fR21(t)*ftau22(t) +...
         pred_p_13(t)*fR12(t)*ftau12(t) + pred_p_14(t)*fR22(t)*ftau12(t) + pred_p_15(t)*fR12(t)*ftau22(t) + pred_p_16(t)*fR22(t)*ftau22(t); % joint density integrated over states
    filter_p_1(t) = pred_p_1(t)*fR11(t)*ftau11(t)/fy; % filtered probability state 1
    filter_p_2(t) = pred_p_2(t)*fR21(t)*ftau11(t)/fy; % filtered probability state 2
    filter_p_3(t) = pred_p_3(t)*fR11(t)*ftau21(t)/fy; % filtered probability state 3
    filter_p_4(t) = pred_p_4(t)*fR21(t)*ftau21(t)/fy; % filtered probability state 4
    filter_p_5(t) = pred_p_5(t)*fR12(t)*ftau11(t)/fy; % filtered probability state 5
    filter_p_6(t) = pred_p_6(t)*fR22(t)*ftau11(t)/fy; % filtered probability state 6
    filter_p_7(t) = pred_p_7(t)*fR12(t)*ftau21(t)/fy; % filtered probability state 7
    filter_p_8(t) = pred_p_8(t)*fR22(t)*ftau21(t)/fy; % filtered probability state 8
    filter_p_9(t) = pred_p_9(t)*fR11(t)*ftau12(t)/fy; % filtered probability state 9
    filter_p_10(t) = pred_p_10(t)*fR21(t)*ftau12(t)/fy; % filtered probability state 10
    filter_p_11(t) = pred_p_11(t)*fR11(t)*ftau22(t)/fy; % filtered probability state 11
    filter_p_12(t) = pred_p_12(t)*fR21(t)*ftau22(t)/fy; % filtered probability state 12
    filter_p_13(t) = pred_p_13(t)*fR12(t)*ftau12(t)/fy; % filtered probability state 13
    filter_p_14(t) = pred_p_14(t)*fR22(t)*ftau12(t)/fy; % filtered probability state 14
    filter_p_15(t) = pred_p_15(t)*fR12(t)*ftau22(t)/fy; % filtered probability state 15
    filter_p_16(t) = pred_p_16(t)*fR22(t)*ftau22(t)/fy; % filtered probability state 16
    filter_pt = [filter_p_1(t);filter_p_2(t);filter_p_3(t);filter_p_4(t);...
                 filter_p_5(t);filter_p_6(t);filter_p_7(t);filter_p_8(t);...
                 filter_p_9(t);filter_p_10(t);filter_p_11(t);filter_p_12(t);...
                 filter_p_13(t);filter_p_14(t);filter_p_15(t);filter_p_16(t)];
    pred_p_1(t+1) = P(1,:)*filter_pt; % prediction probability state 1
    pred_p_2(t+1) = P(2,:)*filter_pt; % prediction probability state 2
    pred_p_3(t+1) = P(3,:)*filter_pt; % prediction probability state 3
    pred_p_4(t+1) = P(4,:)*filter_pt; % prediction probability state 4
    pred_p_5(t+1) = P(5,:)*filter_pt; % prediction probability state 5
    pred_p_6(t+1) = P(6,:)*filter_pt; % prediction probability state 6
    pred_p_7(t+1) = P(7,:)*filter_pt; % prediction probability state 7
    pred_p_8(t+1) = P(8,:)*filter_pt; % prediction probability state 8
    pred_p_9(t+1) = P(9,:)*filter_pt; % prediction probability state 9
    pred_p_10(t+1) = P(10,:)*filter_pt; % prediction probability state 10
    pred_p_11(t+1) = P(11,:)*filter_pt; % prediction probability state 11
    pred_p_12(t+1) = P(12,:)*filter_pt; % prediction probability state 12
    pred_p_13(t+1) = P(13,:)*filter_pt; % prediction probability state 13
    pred_p_14(t+1) = P(14,:)*filter_pt; % prediction probability state 14
    pred_p_15(t+1) = P(15,:)*filter_pt; % prediction probability state 15
    pred_p_16(t+1) = P(16,:)*filter_pt; % prediction probability state 16
end;

pred_prob = [pred_p_1 pred_p_2 pred_p_3 pred_p_4 pred_p_5 pred_p_6 pred_p_7 pred_p_8 pred_p_9 pred_p_10 pred_p_11 pred_p_12 pred_p_13 pred_p_14 pred_p_15 pred_p_16];
filter_prob = [filter_p_1 filter_p_2 filter_p_3 filter_p_4 filter_p_5 filter_p_6 filter_p_7 filter_p_8 filter_p_9 filter_p_10 filter_p_11 filter_p_12 filter_p_13 filter_p_14 filter_p_15 filter_p_16];

%% Obtaining smoothed probabilities [Kim (1994)]
smooth_p_1 = [zeros(T-1,1);filter_p_1(T)];
smooth_p_2 = [zeros(T-1,1);filter_p_2(T)];
smooth_p_3 = [zeros(T-1,1);filter_p_3(T)];
smooth_p_4 = [zeros(T-1,1);filter_p_4(T)];
smooth_p_5 = [zeros(T-1,1);filter_p_5(T)];
smooth_p_6 = [zeros(T-1,1);filter_p_6(T)];
smooth_p_7 = [zeros(T-1,1);filter_p_7(T)];
smooth_p_8 = [zeros(T-1,1);filter_p_8(T)];
smooth_p_9 = [zeros(T-1,1);filter_p_9(T)];
smooth_p_10 = [zeros(T-1,1);filter_p_10(T)];
smooth_p_11 = [zeros(T-1,1);filter_p_11(T)];
smooth_p_12 = [zeros(T-1,1);filter_p_12(T)];
smooth_p_13 = [zeros(T-1,1);filter_p_13(T)];
smooth_p_14 = [zeros(T-1,1);filter_p_14(T)];
smooth_p_15 = [zeros(T-1,1);filter_p_15(T)];
smooth_p_16 = [zeros(T-1,1);filter_p_16(T)];
for t = T-1:-1:1
    auxiliarvector = [smooth_p_1(t+1)/pred_p_1(t+1); smooth_p_2(t+1)/pred_p_2(t+1); smooth_p_3(t+1)/pred_p_3(t+1); smooth_p_4(t+1)/pred_p_4(t+1);...
                      smooth_p_5(t+1)/pred_p_5(t+1); smooth_p_6(t+1)/pred_p_6(t+1); smooth_p_7(t+1)/pred_p_7(t+1); smooth_p_8(t+1)/pred_p_8(t+1);...
                      smooth_p_9(t+1)/pred_p_9(t+1); smooth_p_10(t+1)/pred_p_10(t+1); smooth_p_11(t+1)/pred_p_11(t+1); smooth_p_12(t+1)/pred_p_12(t+1);...
                      smooth_p_13(t+1)/pred_p_13(t+1); smooth_p_14(t+1)/pred_p_14(t+1); smooth_p_15(t+1)/pred_p_15(t+1); smooth_p_16(t+1)/pred_p_16(t+1)];
    smooth_p_1(t) = filter_p_1(t)*(P(:,1)'*auxiliarvector);
    smooth_p_2(t) = filter_p_2(t)*(P(:,2)'*auxiliarvector);
    smooth_p_3(t) = filter_p_3(t)*(P(:,3)'*auxiliarvector);
    smooth_p_4(t) = filter_p_4(t)*(P(:,4)'*auxiliarvector);
    smooth_p_5(t) = filter_p_5(t)*(P(:,5)'*auxiliarvector);
    smooth_p_6(t) = filter_p_6(t)*(P(:,6)'*auxiliarvector);
    smooth_p_7(t) = filter_p_7(t)*(P(:,7)'*auxiliarvector);
    smooth_p_8(t) = filter_p_8(t)*(P(:,8)'*auxiliarvector);
    smooth_p_9(t) = filter_p_9(t)*(P(:,9)'*auxiliarvector);
    smooth_p_10(t) = filter_p_10(t)*(P(:,10)'*auxiliarvector);
    smooth_p_11(t) = filter_p_11(t)*(P(:,11)'*auxiliarvector);
    smooth_p_12(t) = filter_p_12(t)*(P(:,12)'*auxiliarvector);
    smooth_p_13(t) = filter_p_13(t)*(P(:,13)'*auxiliarvector);
    smooth_p_14(t) = filter_p_14(t)*(P(:,14)'*auxiliarvector);
    smooth_p_15(t) = filter_p_15(t)*(P(:,15)'*auxiliarvector);
    smooth_p_16(t) = filter_p_16(t)*(P(:,16)'*auxiliarvector);
end;

smooth_prob = [smooth_p_1 smooth_p_2 smooth_p_3 smooth_p_4 smooth_p_5 smooth_p_6 smooth_p_7 smooth_p_8 smooth_p_9 smooth_p_10 smooth_p_11 smooth_p_12 smooth_p_13 smooth_p_14 smooth_p_15 smooth_p_16];