%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function obtains the predction, filtered and smoothed probabilities
%
% Manuel Gonzalez-Astudillo
% 7/17/13
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [pred_prob, filter_prob, smooth_prob] = estimatedproby1marginalTOBIT(param,data)
%% Setting up parameters
alpha_1 = param(1);
alpha_2 = param(2);
sigma1 = exp(param(3));
p1_11 = exp(param(4))/(1+exp(param(4)));
p1_22 = exp(param(5))/(1+exp(param(5)));
p1_21 = 1-p1_11;
p1_12 = 1-p1_22;
T = size(data,1);

P1 = [p1_11 1-p1_22;
      1-p1_11 p1_22];

A1 = [eye(2)-P1;ones(1,2)];
p1_ = (A1'*A1)\A1';
p1 = p1_(:,3);

%% Setting up data
y1 = data(:,1);
x1 = data(:,2);

%% Obtaining prediction and filtered probabilities
pred_p1_1 = [p1(1);zeros(T,1)];
pred_p1_2 = [p1(2);zeros(T,1)];
filter_p1_1 = zeros(T,1);
filter_p1_2 = zeros(T,1);
fy1_1 = ((normpdf(y1,alpha_1*x1,sigma1)).^(y1>0)).*((1-normcdf(alpha_1*x1,0,sigma1)).^(y1==0)); % density conditional on state 1
fy1_2 = ((normpdf(y1,alpha_2*x1,sigma1)).^(y1>0)).*((1-normcdf(alpha_2*x1,0,sigma1)).^(y1==0)); % density conditional on state 2
for t = 1:T
    fy1 = pred_p1_1(t)*fy1_1(t) + pred_p1_2(t)*fy1_2(t); % density integrated over states
    filter_p1_1(t) = pred_p1_1(t)*fy1_1(t)/fy1; % filtered probability state 1
    filter_p1_2(t) = pred_p1_2(t)*fy1_2(t)/fy1; % filtered probability state 2
    pred_p1_1(t+1) = p1_11*filter_p1_1(t) + p1_12*filter_p1_2(t); % prediction probability state 1
    pred_p1_2(t+1) = p1_21*filter_p1_1(t) + p1_22*filter_p1_2(t); % prediction probability state 2
end;

pred_prob = [pred_p1_1 pred_p1_2];
filter_prob = [filter_p1_1 filter_p1_2];

%% Obtaining smoothed probabilities [Kim (1994)]
smooth_p1_1 = [zeros(T-1,1);filter_p1_1(T)];
smooth_p1_2 = [zeros(T-1,1);filter_p1_2(T)];
for t = T-1:-1:1
    smooth_p1_1(t) = filter_p1_1(t)*(p1_11*smooth_p1_1(t+1)/pred_p1_1(t+1) + p1_21*smooth_p1_2(t+1)/pred_p1_2(t+1));
    smooth_p1_2(t) = filter_p1_2(t)*(p1_12*smooth_p1_1(t+1)/pred_p1_1(t+1) + p1_22*smooth_p1_2(t+1)/pred_p1_2(t+1));
end;

smooth_prob = [smooth_p1_1 smooth_p1_2];