function [statistic1, statistic2] = fun_testing_independence(PS1S2,PS1,PS2,prob_j1_2,prob_j2_2,cut_1,cut_2)
% fun_testing_independence: Computes the tests statististics for the null
% hypothesis of independence as given by Tavare and Altham (1983)
%
% PS1S2: Joint transition matrix
% PS1: Transition matrix of S1
% PS2: Transition matrix of S2
% prob_j1_2: smoothed probabilities S1 state 2
% prob_j2_2: smoothed probabilities S2 state 2
% cut_1: cut-off values for S1
% cut_2: cut-off values for S2
%
%
% Manuel Gonzalez-Astudillo
% 1/9/2017
%%

A = [eye(4)-PS1S2;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5);

n = size(prob_j1_2,1);
lambda = PS1(1,1)+PS1(2,2)-1;
mu = PS2(1,1)+PS2(2,2)-1;
gamma = (1-mu*lambda)/(1+mu*lambda);

statistic1 = zeros(size(cut_1,1),size(cut_2,1));
statistic2 = zeros(size(cut_1,1),size(cut_2,1));
for i = 1:length(cut_1)
    for j = 1:length(cut_2)
        n1 = sum(((1-prob_j1_2)>=cut_1(i)).*((1-prob_j2_2)>=cut_2(j)));
        n2 = sum(((1-prob_j1_2)<cut_1(i)).*((1-prob_j2_2)>=cut_2(j)));
        n3 = sum(((1-prob_j1_2)>cut_1(i)).*((1-prob_j2_2)<cut_2(j)));
        n4 = sum(((1-prob_j1_2)<cut_1(i)).*((1-prob_j2_2)<cut_2(j)));
        Xl2 = ((log(n1*n4/(n2*n3)))^2)/(1/(n*p(1)) + 1/(n*p(2)) + 1/(n*p(3)) + 1/(n*p(4)));
        Cn = n*((n1*n4/(n^2) - n2*n3/(n^2))^2)/((n^(-4))*(n1+n2)*(n1+n3)*(n2+n4)*(n3+n4));
        statistic1(i,j) = gamma*Xl2;
        statistic2(i,j) = gamma*Cn;
    end
end

end

