%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function obtains the log-likelihood function of the parameters of 
% y1 in the M-S model with interdependent switching where the equation of
% y2 is ignored and TOBIT is ignored
%
% Manuel Gonzalez-Astudillo
% 5/30/2013

function loglik = loglikfuny1marginal(param,data)
%% Setting up parameters
alpha_1 = param(1);
alpha_2 = param(2);
sigma1 = exp(param(3));
p1_11 = exp(param(4))/(1+exp(param(4)));
p1_22 = exp(param(5))/(1+exp(param(5)));
p1_21 = 1-p1_11;
p1_12 = 1-p1_22;
T = size(data,1);

P1 = [p1_11 1-p1_22;
      1-p1_11 p1_22];

A1 = [eye(2)-P1;ones(1,2)];
p1_ = (A1'*A1)\A1';
p1 = p1_(:,3);

%% Setting up data
y1 = data(:,1);
x1 = data(:,2);

%% Obtaining log-likelihood function
pred_p1_1 = p1(1); % initial prediction probability
pred_p1_2 = p1(2); % initial prediction probability
fy1_1 = normpdf(y1,alpha_1*x1,sigma1); % density conditional on state 1
fy1_2 = normpdf(y1,alpha_2*x1,sigma1); % density conditional on state 2
loglik = 0;
for t = 1:T
    fy1 = pred_p1_1*fy1_1(t) + pred_p1_2*fy1_2(t); % density integrated over states
    loglik = loglik + log(fy1); % log-likelihood
    filter_p1_1 = pred_p1_1*fy1_1(t)/fy1; % filtered probability state 1
    filter_p1_2 = pred_p1_2*fy1_2(t)/fy1; % filtered probability state 2
    pred_p1_1 = p1_11*filter_p1_1 + p1_12*filter_p1_2; % prediction probability state 1
    pred_p1_2 = p1_21*filter_p1_1 + p1_22*filter_p1_2; % prediction probability state 2
end;

loglik = -loglik;
    