%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function obtains the log-likelihood function of the parameters of 
% y1 in the M-S model with interdependent switching and TOBIT where the 
% equation of y2 is ignored
%
% Manuel Gonzalez-Astudillo
% 5/31/2013

function loglik = loglikfunyjoint(param,data)
%% Setting up parameters
alpha_1 = param(1);
alpha_2 = param(2);
sigma1 = exp(param(3));
gamma_1 = param(4);
gamma_2 = param(5);
sigma2 = exp(param(6));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% j = 1 <-- j1 = 1, j2 = 1;
% j = 2 <-- j1 = 2, j2 = 1;
% j = 3 <-- j1 = 1, j2 = 2;
% j = 4 <-- j1 = 2, j2 = 2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
p_11 = exp(param(7))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_21 = exp(param(8))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_31 = exp(param(9))/(1+exp(param(7))+exp(param(8))+exp(param(9)));
p_41 = 1-p_11-p_21-p_31;
p_12 = exp(param(10))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_22 = exp(param(11))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_32 = exp(param(12))/(1+exp(param(10))+exp(param(11))+exp(param(12)));
p_42 = 1-p_12-p_22-p_32;
p_13 = exp(param(13))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_23 = exp(param(14))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_33 = exp(param(15))/(1+exp(param(13))+exp(param(14))+exp(param(15)));
p_43 = 1-p_13-p_23-p_33;
p_14 = exp(param(16))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_24 = exp(param(17))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_44 = exp(param(18))/(1+exp(param(16))+exp(param(17))+exp(param(18)));
p_34 = 1-p_14-p_24-p_44;

T = size(data,1);

P = [p_11 p_12 p_13 p_14;
     p_21 p_22 p_23 p_24;
     p_31 p_32 p_33 p_34;
     p_41 p_42 p_43 p_44];

A = [eye(4)-P;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5); % unconditional probabilities vector

%% Setting up data
y1 = data(:,1);
y2 = data(:,2);
x1 = data(:,3);
x2 = data(:,4);

%% Obtaining log-likelihood function
pred_p_1 = p(1); % initial prediction probability
pred_p_2 = p(2); % initial prediction probability
pred_p_3 = p(3); % initial prediction probability
pred_p_4 = p(4); % initial prediction probability
fy1_1 = ((normpdf(y1,alpha_1*x1,sigma1)).^(y1>0)).*((1-normcdf(alpha_1*x1,0,sigma1)).^(y1==0)); % density conditional on state 1
fy1_2 = ((normpdf(y1,alpha_2*x1,sigma1)).^(y1>0)).*((1-normcdf(alpha_2*x1,0,sigma1)).^(y1==0)); % density conditional on state 2
fy2_1 = normpdf(y2,gamma_1*x2,sigma2); % density for y2 conditional on state 1
fy2_2 = normpdf(y2,gamma_2*x2,sigma2); % density for y2 conditional on state 2
loglik = 0;
for t = 1:T
    fy = pred_p_1*fy1_1(t)*fy2_1(t) + pred_p_2*fy1_2(t)*fy2_1(t) + pred_p_3*fy1_1(t)*fy2_2(t) + pred_p_4*fy1_2(t)*fy2_2(t); % joint density integrated over states
    loglik = loglik + log(fy); % log-likelihood
    filter_p_1 = pred_p_1*fy1_1(t)*fy2_1(t)/fy; % filtered probability state 1
    filter_p_2 = pred_p_2*fy1_2(t)*fy2_1(t)/fy; % filtered probability state 2
    filter_p_3 = pred_p_3*fy1_1(t)*fy2_2(t)/fy; % filtered probability state 3
    filter_p_4 = pred_p_4*fy1_2(t)*fy2_2(t)/fy; % filtered probability state 4
    pred_p_1 = p_11*filter_p_1 + p_12*filter_p_2 + p_13*filter_p_3 + p_14*filter_p_4; % prediction probability state 1
    pred_p_2 = p_21*filter_p_1 + p_22*filter_p_2 + p_23*filter_p_3 + p_24*filter_p_4; % prediction probability state 2
    pred_p_3 = p_31*filter_p_1 + p_32*filter_p_2 + p_33*filter_p_3 + p_34*filter_p_4; % prediction probability state 3
    pred_p_4 = p_41*filter_p_1 + p_42*filter_p_2 + p_43*filter_p_3 + p_44*filter_p_4; % prediction probability state 4
end;

loglik = -loglik;