function [P1,P2] = marginalprobabilities4(P)
% marginalprobabilities: Obtains the marginal transition probabilities of
% S1 and S2 from a 4x4 transition probability matrix where the entries of 
% P are P(S_{1t},S_{2t}|S_{1t-1},S_{2t-1}
%
% Manuel Gonzalez-Astudillo
% 9/20/2013

A = [eye(4)-P;ones(1,4)];
p_ = (A'*A)\A';
p = p_(:,5); % unconditional probabilities vector

p1_11 = (p(1)*(P(1,1)+P(3,1))+p(3)*(P(1,3)+P(3,3)))/(p(1)+p(3));
p1_22 = (p(2)*(P(2,2)+P(4,2))+p(4)*(P(2,4)+P(4,4)))/(p(2)+p(4));
P1 = [p1_11 1-p1_22;
      1-p1_11 p1_22]; % Transition probability matrix for Sy1
p2_11 = (p(1)*(P(1,1)+P(2,1))+p(2)*(P(1,2)+P(2,2)))/(p(1)+p(2));
p2_22 = (p(3)*(P(3,3)+P(4,3))+p(4)*(P(3,4)+P(4,4)))/(p(3)+p(4));
P2 = [p2_11 1-p2_22;
      1-p2_11 p2_22]; % Transition probability matrix for Sy2
end

