function P8to4 = marginalprobabilities8to4(P,S1,S2,S3)
% marginalprobabilities: Obtains the marginal transition probabilities of
% Si and Sj for i =1 and j = 2,3 from a 8x8 transition probability matrix 
% where the entries of P are P(S_{1t},S_{2t},S_{3t}|S_{1t-1},S_{2t-1},S_{3t-1})
%
% Manuel Gonzalez-Astudillo
% 9/24/2013
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% j = 1 <-- j1 = 1, j2 = 1, j3 = 1
% j = 2 <-- j1 = 2, j2 = 1, j3 = 1
% j = 3 <-- j1 = 1, j2 = 2, j3 = 1
% j = 4 <-- j1 = 2, j2 = 2, j3 = 1
% j = 5 <-- j1 = 1, j2 = 1, j3 = 2
% j = 6 <-- j1 = 2, j2 = 1, j3 = 2
% j = 7 <-- j1 = 1, j2 = 2, j3 = 2
% j = 8 <-- j1 = 2, j2 = 2, j3 = 2

A = [eye(8)-P;ones(1,8)];
p_ = (A'*A)\A';
p = p_(:,9); % unconditional probabilities vector


if S1 == 1 && S3 == 1;
    % [p_{j1',1,j3'}*(P_{j1,1,j3|j1',1,j3'} + P_{j1,2,j3|j1',1,j3'}) + p_{j1',2,j3'}*(P_{j1,1,j3|j1',2,j3'} + P_{j1,2,j3|j1',2,j3'})]/(p_{j1',1,j3'} + p_{j1',2,j3'})

    % j = 1 <-- j1 = 1, j3 = 1
    % j = 2 <-- j1 = 2, j3 = 1
    % j = 3 <-- j1 = 1, j3 = 2
    % j = 4 <-- j1 = 2, j3 = 2

    p_11 = (p(1)*(P(1,1)+P(3,1))+p(3)*(P(1,3)+P(3,3)))/(p(1)+p(3));
    p_21 = (p(1)*(P(2,1)+P(4,1))+p(3)*(P(2,3)+P(4,3)))/(p(1)+p(3));
    p_31 = (p(1)*(P(5,1)+P(7,1))+p(3)*(P(5,3)+P(7,3)))/(p(1)+p(3));
    p_41 = 1-p_11-p_21-p_31;
    p_12 = (p(2)*(P(1,2)+P(3,2))+p(4)*(P(1,4)+P(3,4)))/(p(2)+p(4));
    p_22 = (p(2)*(P(2,2)+P(4,2))+p(4)*(P(2,4)+P(4,4)))/(p(2)+p(4));
    p_32 = (p(2)*(P(5,2)+P(7,2))+p(4)*(P(5,4)+P(7,4)))/(p(2)+p(4));
    p_42 = 1-p_12-p_22-p_32;
    p_13 = (p(5)*(P(1,5)+P(3,5))+p(7)*(P(1,7)+P(3,7)))/(p(5)+p(7));
    p_23 = (p(5)*(P(2,5)+P(4,5))+p(7)*(P(2,7)+P(4,7)))/(p(5)+p(7));
    p_33 = (p(5)*(P(5,5)+P(7,5))+p(7)*(P(5,7)+P(7,7)))/(p(5)+p(7));
    p_43 = 1-p_13-p_23-p_33;
    p_14 = (p(6)*(P(1,6)+P(3,6))+p(8)*(P(1,8)+P(3,8)))/(p(6)+p(8));
    p_24 = (p(6)*(P(2,6)+P(4,6))+p(8)*(P(2,8)+P(4,8)))/(p(6)+p(8));
    p_34 = (p(6)*(P(5,6)+P(7,6))+p(8)*(P(5,8)+P(7,8)))/(p(6)+p(8));
    p_44 = 1-p_14-p_24-p_34;

    P8to4 = [p_11 p_12 p_13 p_14;
             p_21 p_22 p_23 p_24;
             p_31 p_32 p_33 p_34;
             p_41 p_42 p_43 p_44];
end

% j = 1 <-- j1 = 1, j2 = 1, j3 = 1
% j = 2 <-- j1 = 2, j2 = 1, j3 = 1
% j = 3 <-- j1 = 1, j2 = 2, j3 = 1
% j = 4 <-- j1 = 2, j2 = 2, j3 = 1
% j = 5 <-- j1 = 1, j2 = 1, j3 = 2
% j = 6 <-- j1 = 2, j2 = 1, j3 = 2
% j = 7 <-- j1 = 1, j2 = 2, j3 = 2
% j = 8 <-- j1 = 2, j2 = 2, j3 = 2

if S1 == 1 && S2 == 1;
    % [p_{j1',j2',1}*(P_{j1,j2,1|j1',j2',1} + P_{j1,j2,2|j1',j2',1}) + p_{j1',j2',2}*(P_{j1,j2,1|j1',j2',2} + P_{j1,j2,2|j1',j2',2})]/(p_{j1',j2',1} + p_{j1',j2',2})

    % j = 1 <-- j1 = 1, j2 = 1
    % j = 2 <-- j1 = 2, j2 = 1
    % j = 3 <-- j1 = 1, j2 = 2
    % j = 4 <-- j1 = 2, j2 = 2
    
    p_11 = (p(1)*(P(1,1)+P(5,1))+p(5)*(P(1,5)+P(5,5)))/(p(1)+p(5));
    p_21 = (p(1)*(P(2,1)+P(6,1))+p(5)*(P(2,5)+P(6,5)))/(p(1)+p(5));
    p_31 = (p(1)*(P(3,1)+P(7,1))+p(5)*(P(3,5)+P(7,5)))/(p(1)+p(5));
    p_41 = 1-p_11-p_21-p_31;
    p_12 = (p(2)*(P(1,2)+P(5,2))+p(6)*(P(1,6)+P(5,6)))/(p(2)+p(6));
    p_22 = (p(2)*(P(2,2)+P(6,2))+p(6)*(P(2,6)+P(6,6)))/(p(2)+p(6));
    p_32 = (p(2)*(P(3,2)+P(7,2))+p(6)*(P(3,6)+P(7,6)))/(p(2)+p(6));
    p_42 = 1-p_12-p_22-p_32;
    p_13 = (p(3)*(P(1,3)+P(5,3))+p(7)*(P(1,7)+P(5,7)))/(p(3)+p(7));
    p_23 = (p(3)*(P(2,3)+P(6,3))+p(7)*(P(2,7)+P(6,7)))/(p(3)+p(7));
    p_33 = (p(3)*(P(3,3)+P(7,3))+p(7)*(P(3,7)+P(7,7)))/(p(3)+p(7));
    p_43 = 1-p_13-p_23-p_33;
    p_14 = (p(4)*(P(1,4)+P(5,4))+p(8)*(P(1,8)+P(5,8)))/(p(4)+p(8));
    p_24 = (p(4)*(P(2,4)+P(6,4))+p(8)*(P(2,8)+P(6,8)))/(p(4)+p(8));
    p_34 = (p(4)*(P(3,4)+P(7,4))+p(8)*(P(3,8)+P(7,8)))/(p(4)+p(8));
    p_44 = 1-p_14-p_24-p_34;

    P8to4 = [p_11 p_12 p_13 p_14;
             p_21 p_22 p_23 p_24;
             p_31 p_32 p_33 p_34;
             p_41 p_42 p_43 p_44];
end

end

