%% This code evaluates the null hypothesis of independent switching between
% the monetary and fiscal states for different cutting levels of the
% smoothed probabilities
%
% The reference is Tavare and Altham (1983)
%
% Manuel Gonzalez-Astudillo
% 9/16/2013
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Loading estimates
load('prob_jm_2_s_depvarR');
load('prob_jf_2_s_depvarR');
load('prob_jsR_2_s_depvarR');

load('PSmf')
load('PSmsR')
load('PSm');
load('PSf');
load('PSsR');

cut_1 = (0.5:0.01:0.99)';
cut_2 = (0.5:0.01:0.99)';

chi_inv_05 = 3.841458821;
chi_inv_01 = 6.634896601;

%% Testing independence between Sm and SsR
[statistic1, statistic2] = fun_testing_independence(PSmsR,PSm,PSsR,prob_jm_2_s_depvarR,prob_jsR_2_s_depvarR,cut_1,cut_2);
% Creating Plot
[X,Y] = meshgrid(cut_1,cut_2);

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1,...
    'Position',[0.13 0.583837209302326 0.334659090909091 0.341162790697675]);
view(axes1,[-37.5 30]);
axis([0.5 1 0.5 1 0 (max(max(statistic1))+1)])
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
grid(axes1,'on');
hold(axes1,'all');

% Create surf
surf(X,Y,statistic1,'Parent',axes1);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{\sigma_R,t}=1)');

% Create title
title('\gamma X_l^2');

% Create axes
axes2 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.583837209302326 0.334659090909091 0.341162790697675],...
    'Layer','top');
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9]);
box(axes2,'on');
hold(axes2,'all');

% Create contour
contour(X,Y,statistic1,'LineColor',[0 0 0],'LevelList',3.841458821,...
    'Fill','on',...
    'Parent',axes2);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{\sigma_R,t}=1)');

% Create title
title('Contour for \gamma X_l^2 > \chi_{0.95}^2(1)');

% Create axes
axes3 = axes('Parent',figure1,...
    'Position',[0.13 0.11 0.334659090909091 0.341162790697674]);
view(axes3,[-37.5 30]);
axis([0.5 1 0.5 1 0 (max(max(statistic2))+1)])
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
grid(axes3,'on');
hold(axes3,'all');

% Create surf
surf(X,Y,statistic2,'Parent',axes3);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{\sigma_R,t}=1)');

% Create title
title('\gamma C_n');

% Create axes
axes4 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.11 0.334659090909091 0.341162790697674],...
    'Layer','top');
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
box(axes4,'on');
hold(axes4,'all');

% Create contour
contour(X,Y,statistic2,'LineColor',[0 0 0],'LevelList',3.841458821,...
    'Fill','on',...
    'Parent',axes4);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{\sigma_R,t}=1)');

% Create title
title('Contour for \gamma C_n > \chi_{0.95}^2(1)');


%% Testing independence between Sm and Sf
[statistic1, statistic2] = fun_testing_independence(PSmf,PSm,PSf,prob_jm_2_s_depvarR,prob_jf_2_s_depvarR,cut_1,cut_2);
% Creating Plot
[X,Y] = meshgrid(cut_1,cut_2);

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1,...
    'Position',[0.13 0.583837209302326 0.334659090909091 0.341162790697675]);
view(axes1,[-37.5 30]);
axis([0.5 1 0.5 1 0 (max(max(statistic1))+1)])
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
grid(axes1,'on');
hold(axes1,'all');

% Create surf
surf(X,Y,statistic1,'Parent',axes1);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{f,t}=1)');

% Create title
title('\gamma X_l^2');

% Create axes
axes2 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.583837209302326 0.334659090909091 0.341162790697675],...
    'Layer','top');
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
box(axes2,'on');
hold(axes2,'all');

% Create contour
contour(X,Y,statistic1,'LineColor',[0 0 0],'LevelList',3.841458821,...
    'Fill','on',...
    'Parent',axes2);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{f,t}=1)');

% Create title
title('Contour for \gamma X_l^2 > \chi_{0.95}^2(1)');

% Create axes
axes3 = axes('Parent',figure1,...
    'Position',[0.13 0.11 0.334659090909091 0.341162790697674]);
view(axes3,[-37.5 30]);
axis([0.5 1 0.5 1 0 (max(max(statistic2))+1)])
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
grid(axes3,'on');
hold(axes3,'all');

% Create surf
surf(X,Y,statistic2,'Parent',axes3);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{f,t}=1)');

% Create title
title('\gamma C_n');

% Create axes
axes4 = axes('Parent',figure1,...
    'Position',[0.570340909090909 0.11 0.334659090909091 0.341162790697674],...
    'Layer','top');
set(gca,'XTick',[0.5 0.6 0.7 0.8 0.9 1]);
set(gca,'YTick',[0.5 0.6 0.7 0.8 0.9 1]);
box(axes4,'on');
hold(axes4,'all');

% Create contour
contour(X,Y,statistic2,'LineColor',[0 0 0],'LevelList',3.841458821,...
    'Fill','on',...
    'Parent',axes4);

% Create xlabel
xlabel('Cut-off for Prob(S_{m,t}=1)');

% Create ylabel
ylabel('Cut-off for Prob(S_{f,t}=1)');

% Create title
title('Contour for \gamma C_n > \chi_{0.95}^2(1)');